<?php

/**
 * Plugin Name: Cirrus Shield Forms for WordPress
 * Plugin URI: https://www.cirrus-shield.net/
 * Description: Easily integrate a WordPress form with Cirrus Shield
 * Version: 20210309
 * Author: Cirrus Shield
 * Author URI: https://www.cirrus-shield.com/
 * License: License: GPLv2 or later
 * License URI: http://www.gnu.org/licenses/gpl-2.0.html
 *
 */
/**
 * Application entry point. Contains plugin startup class that loads on <i> cirrusshield_init </i> action.
 */
global $wpdb;
if (!class_exists('Cirrus')) {
    require_once('inc/cirrus.php');
}
// For marketing automation.
if (!class_exists('Cirrusshield')) {
    require_once('inc/cirrusshield.php');
}
if (!class_exists('CS_Manager')) {
    register_deactivation_hook(__FILE__, array('CS_Manager', 'deactivate'));
    register_activation_hook(__FILE__, array('CS_Manager', 'install'));
    register_uninstall_hook(__FILE__, array('CS_Manager', 'uninstall'));
    require_once('page/page-home.php');
    require_once('page/page-form.php');
    require_once('page/page-lists.php');
    require_once('page/page-log.php');
    require_once('page/page-customformlog.php');
    require_once('page/page-campaigns.php');
    require_once('page/page-statistics.php');
    require_once('page/page-scenarios.php');
    require_once('widget/widget_form.php');
    require_once('inc/table-forms.php');
    require_once('inc/cs-api-manager.php');
    require_once('inc/cs-sms-code.php');
    require_once('model/model-forms.php');
    require_once('model/model-users.php');
    require_once('model/model-lang.php');
    /**
     * Class CS_Manager
     */
    class CS_Manager
    {
        /** Main setting option name */
        const MAIN_OPTION_NAME = 'csmain_option';
        /** Home setting option name */
        const HOME_OPTION_NAME = 'cshome_option';
        /** Access token option name */
        const ACCESS_TOKEN_OPTION_NAME = 'cstoken_store';
        /** Plugin language notice option name */
        const LANGUAGE_OPTION_NAME = 'cslanguage_notice_option';
        /** Temp list of Dopt option name */
        const TEMPLIST_OPTION_NAME = 'cstemp_list';
        /** Form preview option name */
        const PREVIEW_OPTION_NAME = 'cspreview_form';
        /** Request url of cirrusshield api */
        const CIRRUSSHIELD_API_URL = 'https://www.cirrus-shield.net/RestApi';
        /**
         * API Credentials
         *
         * @var $username
         * @var $password
         */
        public static $access_key;
        public static $username;
        public static $password;
        /**
         * Store instance
         *
         * @var $instance
         */
        public static $instance;
        /**
         * Plugin directory path value. set in constructor
         *
         * @var $plugin_dir
         */
        public static $plugin_dir;
        /**
         * Plugin url. set in constructor
         *
         * @var $plugin_url
         */
        public static $plugin_url;
        /**
         * Plugin name. set in constructor
         *
         * @var $plugin_name
         */
        public static $plugin_name;
        /**
         * Check if wp_mail is declared
         *
         * @var $wp_mail_conflict
         */
        static $wp_mail_conflict;
        /**
         * Class constructor
         * Sets plugin url and directory and adds hooks to <i>init</i>. <i>admin_menu</i>
         */
        function __construct()
        {
            // get basic info.
            self::$plugin_dir = plugin_dir_path(__FILE__);
            self::$plugin_url = plugins_url('', __FILE__);
            self::$plugin_name = plugin_basename(__FILE__);
            self::$wp_mail_conflict = false;
            // api key for cirrusshield.
            $general_settings = get_option(self::MAIN_OPTION_NAME, array());
            self::$access_key = isset($general_settings['access_key']) ? $general_settings['access_key'] : '';
            self::$username = isset($general_settings['username']) ? $general_settings['username'] : '';
            self::$password = isset($general_settings['password']) ? $general_settings['password'] : '';
            self::$instance = $this;
            add_action('admin_init', array(&$this, 'admin_init'), 9999);
            add_action('admin_menu', array(&$this, 'admin_menu'), 9999);
            add_action('wp_print_scripts', array(&$this, 'frontend_register_scripts'), 9999);
            add_action('wp_enqueue_scripts', array(&$this, 'wp_head_ac'), 999);
            // create custom url for form preview.
            add_filter('query_vars', array(&$this, 'csquery_vars'));
            add_action('parse_request', array(&$this, 'csparse_request'));
            add_action('wp_ajax_csvalidate_process', array('CS_Page_Home', 'ajax_validation_process'));
            add_action('wp_ajax_csvalidate_ma', array('CS_Page_Home', 'ajax_validate_ma'));
            add_action('wp_ajax_csactivate_email_change', array('CS_Page_Home', 'ajax_activate_email_change'));
            add_action('wp_ajax_cssender_change', array('CS_Page_Home', 'ajax_sender_change'));
            add_action('wp_ajax_cssend_email', array('CS_Page_Home', 'ajax_send_email'));
            add_action('wp_ajax_csremove_cache', array('CS_Page_Home', 'ajax_remove_cache'));
            add_action('wp_ajax_cssync_users', array('CS_Page_Home', 'ajax_sync_users'));
            add_action('wp_ajax_cschange_template', array('CS_Page_Form', 'ajax_change_template'));
            add_action('wp_ajax_csget_lists', array('CS_Page_Form', 'ajax_get_lists'));
            add_action('wp_ajax_csget_templates', array('CS_Page_Form', 'ajax_get_templates'));
            add_action('wp_ajax_csget_attributes', array('CS_Page_Form', 'ajax_get_attributes'));
            add_action('wp_ajax_csupdate_form_html', array('CS_Page_Form', 'ajax_update_html'));
            add_action('wp_ajax_cscopy_origin_form', array('CS_Page_Form', 'ajax_copy_origin_form'));
            add_action('wp_ajax_csget_country_prefix', array($this, 'ajax_get_country_prefix'));
            add_action('wp_ajax_nopriv_csget_country_prefix', array($this, 'ajax_get_country_prefix'));
            add_action('init', array(&$this, 'init'));
            add_action('wp_login', array(&$this, 'cswp_login_identify'), 10, 2);
            // change cs tables name on prior(2.6.9) versions.
            CS_Model_Users::add_prefix();
            CS_Forms::add_prefix();
            add_shortcode('cswp_form', array(&$this, 'cswp_form_shortcode'));
            // register widget.
            add_action('widgets_init', array(&$this, 'cscreate_widget'));
            if (self::is_done_validation() === true) {
                add_shortcode('cswp_form', array(&$this, 'cswp_form_shortcode'));
                // register widget.
                add_action('widgets_init', array(&$this, 'cscreate_widget'));
                // create forms tables and create default form.
                CS_Forms::createTable();
                // create users table.
                CS_Model_Users::createTable();
                CS_Model_Users::alterTable();
                // add columns for old versions
                CS_Forms::alterTable();
            }
            $use_api_version = get_option('csuse_apiv2', '0');
            if ('0' === $use_api_version) {
                self::uninstall();
                update_option('csuse_apiv2', '1');
            }
            // Wpml plugin part.
            if (!function_exists('is_plugin_active_for_network')) :
                require_once(ABSPATH . '/wp-admin/includes/plugin.php');
            endif;
            if (in_array('sitepress-multilingual-cms/sitepress.php', apply_filters('active_plugins', get_option('active_plugins'))) || is_plugin_active_for_network('sitepress-multilingual-cms/sitepress.php')) {
                CS_Forms_Lang::createTable();
                add_action('cslanguage_sidebar', array($this, 'cscreate_language_sidebar'));
            }
            /**
             * Hook wp_mail to send transactional emails
             */
            // check if wp_mail function is already declared by others.
            if (function_exists('wp_mail')) {
                self::$wp_mail_conflict = true;
            }
            $home_settings = get_option(CS_Manager::HOME_OPTION_NAME, array());
            if ('yes' === $home_settings['activate_email']) {
                if (false === self::$wp_mail_conflict) {
                    /**
                     * Declare wp_mail function for CirrusShield SMTP module
                     *
                     * @param string $to - receiption email.
                     * @param string $subject - subject of email.
                     * @param string $message - message content.
                     * @param string $headers - header of email.
                     * @param array  $attachments - attachments.
                     * @return bool
                     */
                    function wp_mail($to, $subject, $message, $headers = '', $attachments = array())
                    {
                        $message = str_replace('NF_CS', '', $message);
                        $message = str_replace('WC_CS', '', $message);
                        try {
                            $sent = CS_Manager::csemail($to, $subject, $message, $headers, $attachments);
                            if (is_wp_error($sent) || !isset($sent['code']) || 'success' !== $sent['code']) {
                                return CS_Manager::wp_mail_native($to, $subject, $message, $headers, $attachments);
                            }
                            return true;
                        } catch (Exception $e) {
                            return CS_Manager::wp_mail_native($to, $subject, $message, $headers, $attachments);
                        }
                    }
                } else {
                    add_action('admin_notices', array(&$this, 'wpMailNotices'));
                    return;
                }
            }
        }
        /**
         * Add identify tag for login users
         *
         * @param string $user_login - user login name.
         * @param array  $user - user.
         */
        function cswp_login_identify($user_login, $user)
        {
            $userEmail = $user->user_email;
            $data = array(
                'email_id' => $userEmail,
                'name' => $user_login,
            );
            CS_API_Manager::identify_user($data);
        }
        /**
         * Initialize method. called on <i>init</i> action
         */
        function init()
        {
            // Sign up process.
            if (isset($_POST['csform_action']) && ('subscribe_form_submit' == $_POST['csform_action'])) {
                $this->signup_process();
            }
            if (isset($_POST['csform_action']) && ('cs_form_submit' == $_POST['csform_action'])) {
                $this->csformaction_process();
            }
            // Subscribe.
            if (isset($_GET['csaction']) && ('subscribe' == $_GET['csaction'])) {
                CS_API_Manager::subscribe();
                exit;
            }
            /** Logout from Cirrus-shield */
            if (isset($_GET['logoutcs']) && ('loginout' == $_GET['logoutcs'])) {
                global $wpdb;
                if (!$wpdb) {
                    $wpdb = new WPDB('root', '', 'worddumb', 'localhost');
                } else {
                    global $wpdb;
                }
                $wpdb->query("DELETE FROM `wp_options` WHERE `option_name` = 'csmain_option'");
                $index = $wpdb->get_var('SELECT `id` FROM wp_cslog ORDER BY `id` DESC LIMIT 1 ;');
                $wpdb->query("UPDATE `wp_cslog` SET logouttime = '" . time() . "', status = 'Log-out - Success' WHERE id = " . $index . ";");
                $index1 = $wpdb->get_var('SELECT `id` FROM wp_cs_login_log ORDER BY `id` DESC LIMIT 1 ;');
                $wpdb->query("UPDATE `wp_cs_login_log` SET status = 'deactive' WHERE id = " . $index1 . ";");
                //                exit;
                wp_safe_redirect("https://www.cirrus-shield.fr/wp-admin/admin.php?page=cspage_home");
            }
            // Dismiss language notice.
            if (isset($_GET['dismiss_admin_lang_notice']) && '1' == $_GET['dismiss_admin_lang_notice']) {
                update_option(CS_Manager::LANGUAGE_OPTION_NAME, true);
                wp_safe_redirect($_SERVER['HTTP_REFERER']);
                exit();
            }
            add_action('wp_head', array(&$this, 'install_ma_script'));
        }
        /**
         * Hook admin_init
         */
        function admin_init()
        {
            add_action('admin_action_cssetting_subscription', array('CS_Page_Form', 'save_setting_subscription'));
            add_action('admin_action_nopriv_cssetting_subscription', array('CS_Page_Form', 'save_setting_subscription'));
            CS_Manager::LoadTextDomain();
            $this->register_scripts();
            $this->register_styles();
        }
        /**
         * Hook admin_menu
         */
        function admin_menu()
        {
            CS_Manager::LoadTextDomain();
            new CS_Page_Home();
            new CS_Page_Form();
            new CS_Page_Lists();
            new CS_Page_Log();
            new CS_Page_Customformlog();
            new CS_Page_Campaigns();
            new CS_Page_Statistics();
            $home_settings = get_option(CS_Manager::HOME_OPTION_NAME);
            if (isset($home_settings['activate_ma']) && 'yes' == $home_settings['activate_ma']) {
                new CS_Page_Scenarios();
            }
        }
        /**
         * Register script for admin page
         */
        function register_scripts()
        {
            wp_register_script('cs-bootstrap-js', self::$plugin_url . '/js/bootstrap/js/bootstrap.min.js', array('jquery'), null);
            wp_register_script('cs-admin-js', self::$plugin_url . '/js/admin.js', array('jquery'), filemtime(self::$plugin_dir . '/js/admin.js'));
            wp_register_script('cs-chosen-js', self::$plugin_url . '/js/chosen.jquery.min.js', array('jquery'), null);
        }
        /**
         * Register stylesheet for admin page
         */
        function register_styles()
        {
            wp_register_style('cs-bootstrap-css', self::$plugin_url . '/js/bootstrap/css/bootstrap.css', array(), null, 'all');
            wp_register_style('cs-fontawesome-css', self::$plugin_url . '/css/fontawesome/css/font-awesome.css', array(), null, 'all');
            wp_register_style('cs-chosen-css', self::$plugin_url . '/css/chosen.min.css');
            wp_register_style('cs-admin-css', self::$plugin_url . '/css/admin.css', array(), filemtime(self::$plugin_dir . '/css/admin.css'), 'all');
        }
        /**
         * Registers scripts for frontend
         */
        function frontend_register_scripts()
        {
        }
        /**
         * Enqueue script on front page
         */
        function wp_head_ac()
        {
            wp_enqueue_script('cs-front-js', self::$plugin_url . '/js/cirrus-front.js', array('jquery'), filemtime(self::$plugin_dir . '/js/cirrus-front.js'), false);
            wp_enqueue_style('cs-front-css', self::$plugin_url . '/css/cirrus-front.css', array(), array(), 'all');
            wp_localize_script(
                'cs-front-js',
                'csErrMsg',
                array(
                    'invalidMail' => __('Please fill out valid email address', 'cslang'),
                    'requiredField' => __('Please fill out required fields', 'cslang'),
                    'invalidDateFormat' => __('Please fill out valid date format', 'cslang'),
                    'invalidSMSFormat' => __('Please fill out valid phone number', 'cslang'),
                )
            );
            wp_localize_script(
                'cs-front-js',
                'ajax_csfront_object',
                array(
                    'ajax_url' => admin_url('admin-ajax.php'),
                    'ajax_nonce' => wp_create_nonce('csfront_ajax_nonce'),
                    'flag_url' => plugins_url('img/flags/', __FILE__),
                )
            );
        }
        /**
         * Install method is called once install this plugin.
         * create tables, default option ...
         */
        static function install()
        {
            $general_settings = get_option(self::MAIN_OPTION_NAME, array());
            $access_key = isset($general_settings['access_key']) ? $general_settings['access_key'] : '';
            $username = isset($general_settings['username']) ? $general_settings['username'] : '';
            $password = isset($general_settings['password']) ? $general_settings['password'] : '';
            if ('' === $username && '' === $password) {
                // Default option when activate.
                $home_settings = array(
                    'activate_email' => 'no',
                    'activate_ma' => 'no',
                );
                update_option(self::HOME_OPTION_NAME, $home_settings);
            }
        }
        /**
         * Uninstall method is called once uninstall this plugin
         * delete tables, options that used in plugin
         */
        static function uninstall()
        {
            $setting = array();
            update_option(CS_Manager::MAIN_OPTION_NAME, $setting);
            $home_settings = array(
                'activate_email' => 'no',
                'activate_ma' => 'no',
            );
            update_option(CS_Manager::HOME_OPTION_NAME, $home_settings);
            // Delete access_token.
            $token_settings = array();
            update_option(CS_Manager::ACCESS_TOKEN_OPTION_NAME, $token_settings);
            // Empty tables.
            CS_Model_Users::removeTable();
            CS_Forms::removeTable();
            CS_Forms_Lang::removeTable();
            // Remove all transient.
            CS_API_Manager::remove_transients();
        }
        /**
         * Deactivate method is called once deactivate this plugin
         */
        static function deactivate()
        {
            update_option(CS_Manager::LANGUAGE_OPTION_NAME, false);
            // Remove sync users option.
            delete_option('cssync_users');
            // Remove all transient.
            CS_API_Manager::remove_transients();
        }
        /**
         * Check that have done validation process already.
         */
        static function is_done_validation()
        {
            $general_settings = get_option(self::MAIN_OPTION_NAME, array());
            $username = isset($general_settings['username']) ? $general_settings['username'] : '';
            $password = isset($general_settings['password']) ? $general_settings['password'] : '';
            if ('' !== $username && '' !== $password) {
                return true;
            } else {
                return false;
            }
        }
        /**
         * Install marketing automation script in header
         */
        function install_ma_script()
        {
            $home_settings = get_option(CS_Manager::HOME_OPTION_NAME, array());
            if (isset($home_settings['activate_ma']) && 'yes' == $home_settings['activate_ma']) {
                $general_settings = get_option(CS_Manager::MAIN_OPTION_NAME, array());
                $ma_key = $general_settings['ma_key'];
                $output = '<script type="text/javascript">
            (function() {window.cs ={equeue:[],client_key:"' . $ma_key . '"};/* OPTIONAL: email for identify request*/window.cirrusshield = {}; for (var j = [\'track\', \'identify\', \'trackLink\', \'page\'], i = 0; i < j.length; i++) { (function(k) { window.cirrusshield[k] = function() { var arg = Array.prototype.slice.call(arguments); (window.cs[k] || function() { var t = {}; t[k] = arg; window.cs.equeue.push(t);})(arg[0], arg[1], arg[2]);};})(j[i]);}var n = document.createElement("script"),i = document.getElementsByTagName("script")[0]; n.type = "text/javascript", n.id = "cirrusshield-js", n.async = !0, n.src = "https://sibautomation.com/sa.js?key=" + window.cs.client_key, i.parentNode.insertBefore(n, i), window.cirrusshield.page();})();
            </script>';
                echo $output;
            }
        }
        /**
         * Register widget
         */
        function cscreate_widget()
        {
            register_widget('CS_Widget_Subscribe');
        }
        /**
         * Display form on front page
         *
         * @param string $frmID - form ID.
         * @param string $lang - form language.
         */
        function generate_form_box($frmID = '-1', $lang = '')
        {
            if ('oldForm' == $frmID) {
                $frmID = get_option('csold_form_id');
            } elseif ('' != $lang) {
                $trans_id = CS_Forms_Lang::get_form_ID($frmID, $lang);
                if (null != $trans_id) {
                    $frmID = $trans_id;
                }
            }
            $formData = CS_Forms::getForm($frmID);
            if (empty($formData)) {
                return;
            }
            // Add Google recaptcha
            if ('0' != $formData['gCaptcha']) {
                if ('1' == $formData['gCaptcha']) {   // For old forms.
                    $formData['html'] = preg_replace('/([\s\S]*?)<div class="g-recaptcha"[\s\S]*?data-size="invisible"><\/div>/', '$1', $formData['html']);
                }
                if ('3' == $formData['gCaptcha']) {     // The case of using google recaptcha.
?>
                    <script type="text/javascript">
                        var gCaptchaSibWidget;
                        var onloadSibCallback = function() {
                            gCaptchaSibWidget = grecaptcha.render('cscaptcha', {
                                'sitekey': '<?php echo $formData["gCaptcha_site"] ?>'
                            });
                        };
                    </script>
                <?php
                } else {                                  // The case of using google invisible recaptcha.
                ?>
                    <script type="text/javascript">
                        var gCaptchaSibWidget;
                        var onloadSibCallback = function() {
                            var element = document.getElementsByClassName('cs-default-btn');
                            gCaptchaSibWidget = grecaptcha.render(element[0], {
                                'sitekey': '<?php echo $formData["gCaptcha_site"] ?>',
                                'callback': csVerifyCallback
                            });
                        };
                    </script>
                <?php
                }
                ?>
                <script src="https://www.google.com/recaptcha/api.js?onload=onloadSibCallback&render=explicit" async defer></script>
            <?php
            }
            ?>
            <form id="cssignup_form_<?php echo esc_attr($frmID); ?>" method="post" class="cssignup_form" enctype="multipart/form-data">
                <div class="csloader" style="display:none;"><img src="<?php echo esc_url(includes_url()); ?>/images/spinner.gif" alt="loader"></div>
                <input type="hidden" name="csform_action" value="cs_form_submit">
                <input type="hidden" name="csform_id" value="<?php echo esc_attr($frmID); ?>">
                <input type="hidden" name="moduleID" value="<?php echo esc_attr($formData['moduleID']); ?>">
                <input type="hidden" name="csform_alert_notice" value="<?php echo esc_attr($formData['requiredMsg']); ?>">
                <div class="cssignup_box_inside_<?php echo esc_attr($frmID); ?>">
                    <div style="/*display:none*/" class="csmsg_disp">
                    </div>
                    <?php
                    echo $formData['html'];
                    ?>
                </div>
            </form>
            <style>
                <?php
                if (!$formData['dependTheme']) {
                    // Custom css.
                    $formData['css'] = str_replace('[form]', 'form#cssignup_form_' . $frmID, $formData['css']);
                    echo $formData['css'];
                }
                $msgCss = str_replace('[form]', 'form#cssignup_form_' . $frmID, CS_Forms::getDefaultMessageCss());
                echo $msgCss;
                ?>
            </style>
            <?php
        }
        /**
         * Shortcode for sign up form
         *
         * @param array $atts - shortcode parameter.
         * @return string
         */
        function cswp_form_shortcode($atts)
        {
            $pull_atts = shortcode_atts(
                array(
                    'id' => 'oldForm', // We will return 'oldForm' for shortcode of old form.
                ),
                $atts
            );
            $frmID = $pull_atts['id'];
            $lang = defined('ICL_LANGUAGE_CODE') ? ICL_LANGUAGE_CODE : '';
            ob_start();
            $this->generate_form_box($frmID, $lang);
            $output_string = ob_get_contents();
            ob_end_clean();
            return $output_string;
        }
        /**
         * Sign up process
         */
        function signup_process()
        {
            check_ajax_referer('csfront_ajax_nonce', 'security');
            $formID = isset($_POST['csform_id']) ? sanitize_text_field($_POST['csform_id']) : 1;
            if ('oldForm' == $formID) {
                $formID = get_option('csold_form_id');
            }
            $formData = CS_Forms::getForm($formID);
            if ('0' != $formData['gCaptcha']) {
                if (!isset($_POST['g-recaptcha-response']) || empty($_POST['g-recaptcha-response'])) {
                    wp_send_json(
                        array(
                            'status' => 'gcaptchaEmpty',
                            'msg' => 'Please click on the reCAPTCHA box.',
                        )
                    );
                }
                $secret = $formData['gCaptcha_secret'];
                $data = array(
                    'secret' => $secret,
                    'response' => sanitize_text_field($_POST['g-recaptcha-response']),
                );
                $verify = curl_init();
                curl_setopt($verify, CURLOPT_URL, 'https://www.google.com/recaptcha/api/siteverify');
                curl_setopt($verify, CURLOPT_POST, true);
                curl_setopt($verify, CURLOPT_POSTFIELDS, http_build_query($data));
                curl_setopt($verify, CURLOPT_SSL_VERIFYPEER, false);
                curl_setopt($verify, CURLOPT_RETURNTRANSFER, true);
                $response = curl_exec($verify);
                $responseData = json_decode($response);
                if (!$responseData->success) {
                    wp_send_json(
                        array(
                            'status' => 'gcaptchaFail',
                            'msg' => 'Robot verification failed, please try again.',
                        )
                    );
                }
            }
            $listID = $formData['listID'];
            $interestingLists = isset($_POST['interestingLists']) ? $_POST['interestingLists'] : array();
            $expectedLists = isset($_POST['listIDs']) ? $_POST['listIDs'] : array();
            if (empty($interestingLists)) {
                $unlinkedLists = null;
            } else {
                $unwantedLists = array_diff($interestingLists, $expectedLists);
                $unlinkedLists = array_diff($unwantedLists, $listID);
                $listID = array_unique(array_merge($listID, $expectedLists));
            }
            $email = isset($_POST['email']) ? sanitize_text_field($_POST['email']) : '';
            if (!is_email($email)) {
                return;
            }
            $isDoubleOptin = $formData['isDopt'];
            $isOptin = $formData['isOpt'];
            $redirectUrlInEmail = $formData['redirectInEmail'];
            $redirectUrlInForm = $formData['redirectInForm'];
            $info = array();
            $attributes = explode(',', $formData['attributes']); // String to array.
            if (isset($attributes) && is_array($attributes)) {
                foreach ($attributes as $attribute) {
                    $info[$attribute] = isset($_POST[$attribute]) ? sanitize_text_field($_POST[$attribute]) : '';
                }
            }
            $templateID = $formData['templateID'];
            if ($isDoubleOptin) {
                /*
                 * Double optin process
                 * 1. add/update user in CS contacts
                 * 2. add record to db
                 * 3. send confirmation email with activate code
                 */
                // Create/updated subscriber.
                $result = CS_API_Manager::create_subscriber('double-optin', $email, $listID, $info, $unlinkedLists);
                // Send a double optin confirm email.
                if ('success' == $result) {
                    // Add a recode with activate code in db.
                    $activateCode = $this->create_activate_code($email, $info, $formID, $listID, $redirectUrlInEmail, $unlinkedLists);
                    CS_API_Manager::send_comfirm_email('double-optin', $email, $templateID, $info, $activateCode);
                }
            } elseif ($isOptin) {
                $result = CS_API_Manager::create_subscriber('confirm', $email, $listID, $info, $unlinkedLists);
                if ('success' == $result) {
                    // Send a confirm email.
                    CS_API_Manager::send_comfirm_email('confirm', $email, $templateID, $info);
                }
            } else {
                $result = CS_API_Manager::create_subscriber('simple', $email, $listID, $info, $unlinkedLists);
            }
            $msg = array(
                'successMsg' => $formData['successMsg'],
                'errorMsg' => $formData['errorMsg'],
                'existMsg' => $formData['existMsg'],
                'invalidMsg' => $formData['invalidMsg'],
            );
            wp_send_json(
                array(
                    'status' => $result,
                    'msg' => $msg,
                    'redirect' => $redirectUrlInForm,
                )
            );
        }

        function ajax_validation_process_custom_form_submit()
        {
            global $wpdb;
            //                        if (!$wpdb) {
            //
            //                                    $wpdb = new WPDB( 'root', '', 'worddumb', 'localhost');
            //
            //                                } else {
            //                                    global $wpdb; 
            //                                }
            //                            echo '3456';exit;
            //			check_ajax_referer( 'ajax_csadmin_nonce', 'security' );
            $getdata = $wpdb->get_results("SELECT * FROM `wp_cs_login_log` WHERE 1 ORDER BY `id` DESC;");
            if ($getdata[0]->status === 'active') {
                $username = $getdata[0]->username;
                $password = $getdata[0]->password;
                try {
                    $cirrus = new Cirrus(CS_Manager::CIRRUSSHIELD_API_URL, $username, $password);
                } catch (Exception $e) {
                    if ($e->getMessage() == 'Cirrus requires CURL module') {
                        wp_send_json('curl_no_installed');
                    } else {
                        wp_send_json('curl_error');
                    }
                }
                $access_token = $cirrus->get_access_tokens();
            } else {
                $username = '';
                $password = '';
                $access_token = '';
            }
            if ($access_token != '') {
                $settings = array(
                    'username' => $username,
                    'password' => $password,
                );
                update_option(CS_Manager::MAIN_OPTION_NAME, $settings);
                CS_Manager::$username = $username;
                CS_Manager::$password = $password;
                $token_settings = array(
                    'access_token' => $access_token,
                );
                update_option(CS_Manager::ACCESS_TOKEN_OPTION_NAME, $token_settings);
                //                                 
                return 1;
            } else {
                return 0;
            }
        }

        function csformaction_process()
        {
            //            print_r($this->ajax_validation_process_custom_form_submit());exit;
            global $wpdb;
            if ($this->ajax_validation_process_custom_form_submit() != 1) {
                //                if (!$wpdb) {
                //
                //                    $wpdb = new WPDB( 'root', '', 'worddumb', 'localhost');
                //
                //                } else {
                //
                //                    global $wpdb; 
                //
                //                }
                $xmlParts1 = '';
                $xmlParts1 .= '<First_Name>' . (isset($_POST['First_Name']) ? ($_POST['First_Name']) : '') . '</First_Name> ';
                $xmlParts1 .= '<Last_Name>' . (isset($_POST['Last_Name']) ? ($_POST['Last_Name']) : '') . '</Last_Name> ';
                $xmlParts1 .= '<Email>' . (isset($_POST['Email']) ? sanitize_text_field($_POST['Email']) : '') . '</Email> ';
                $xmlParts1 .= '<Phone>' . (isset($_POST['Phone']) ? sanitize_text_field($_POST['Phone']) : '') . '</Phone> ';
                $xmlParts1 .= '<Country>' . (isset($_POST['Country']) ? sanitize_text_field($_POST['Country']) : '') . '</Country> ';
                $xmlParts1 .= '<Souscription_Newsletter>' . (isset($_POST['Souscription_Newsletter']) && $_POST['Souscription_Newsletter'] == 'on' ? sanitize_text_field($_POST['Souscription_Newsletter']) : 'off') . '</Souscription_Newsletter> ';
                $xmlData1 = ("<Data> 
                            <" . $_POST['moduleID'] . ">
                            " . $xmlParts1 . "
                            </" . $_POST['moduleID'] . ">
                            </Data>");
                //                $queryline = 'CREATE TABLE IF NOT EXISTS wp_cs_unsubmitted_forms (
                //
                //                            `id` int(20) NOT NULL AUTO_INCREMENT,
                //
                //                            `xmldata` LONGTEXT,
                //
                //                            `datetime` LONGTEXT,
                //
                //                            PRIMARY KEY (`id`)
                //
                //                            );';
                //
                //                $wpdb->query( $queryline );
                $datetime = date("d-m-Y H:i", strtotime("now"));
                $wpdb->query("INSERT INTO `wp_cs_unsubmitted_forms` (xmldata, datetime) VALUES ('" . $xmlData1 . "', '" . $datetime . "');");
                $getdata = $wpdb->get_results("SELECT * FROM `wp_cs_custom_set` WHERE 1;");
                $errmsg = $getdata[0]->set_value;
                $csemail = $getdata[1]->set_value;
                $headers = array('Content-Type: text/html; charset=UTF-8');
                wp_mail($csemail, 'Un-successful Submission of Form. Cirrus-Shield is +.', "Please find below the un-submitted form data in xml format. <br />" . htmlentities($xmlData1), $headers);
                $result['code'] = '404';
                $result['message'] = $errmsg;
                $result['guid'] = '';
                $msg['errorMsg'] = $errmsg;
                wp_send_json(
                    array(
                        'status' => $result,
                        'msg' => $msg,
                    )
                );
            } else {
                check_ajax_referer('csfront_ajax_nonce', 'security');
                $formID = isset($_POST['csform_id']) ? sanitize_text_field($_POST['csform_id']) : 1;
                if ('oldForm' == $formID) {
                    $formID = get_option('csold_form_id');
                }
                $formData = CS_Forms::getForm($formID);
                if ('0' != $formData['gCaptcha']) {
                    if (!isset($_POST['g-recaptcha-response']) || empty($_POST['g-recaptcha-response'])) {
                        wp_send_json(
                            array(
                                'status' => 'gcaptchaEmpty',
                                'msg' => 'Please click on the reCAPTCHA box.',
                            )
                        );
                    }
                    $secret = $formData['gCaptcha_secret'];
                    $data = array(
                        'secret' => $secret,
                        'response' => sanitize_text_field($_POST['g-recaptcha-response']),
                    );
                    $verify = curl_init();
                    curl_setopt($verify, CURLOPT_URL, 'https://www.google.com/recaptcha/api/siteverify');
                    curl_setopt($verify, CURLOPT_POST, true);
                    curl_setopt($verify, CURLOPT_POSTFIELDS, http_build_query($data));
                    curl_setopt($verify, CURLOPT_SSL_VERIFYPEER, false);
                    curl_setopt($verify, CURLOPT_RETURNTRANSFER, true);
                    $response = curl_exec($verify);
                    $responseData = json_decode($response);
                    if (!$responseData->success) {
                        wp_send_json(
                            array(
                                'status' => 'gcaptchaFail',
                                'msg' => 'Robot verification failed, please try again.',
                            )
                        );
                    }
                }
                $listID = $formData['listID'];
                $interestingLists = isset($_POST['interestingLists']) ? $_POST['interestingLists'] : array();
                $expectedLists = isset($_POST['listIDs']) ? $_POST['listIDs'] : array();
                if (empty($interestingLists)) {
                    $unlinkedLists = null;
                } else {
                    $unwantedLists = array_diff($interestingLists, $expectedLists);
                    $unlinkedLists = array_diff($unwantedLists, $listID);
                    $listID = array_unique(array_merge($listID, $expectedLists));
                }
                $isDoubleOptin             = $formData['isDopt'];
                $isEmailDoubleOptin     = $formData['emailDopt'];
                $isDatetimeDopt         = $formData['datetimeDopt'];
                $isOptin                 = $formData['isOpt'];
                $redirectUrlInEmail     = $formData['redirectInEmail'];
                $redirectUrlInForm         = $formData['redirectInForm'];
                $isEmailSpecific        = $formData['isEmailSpecific'];
                $emailSpecificIdForm     = $formData['emailSpecificId'];
                $attributes_type        = unserialize($formData['attributes_type']);
                $datetime_local         = CS_API_Manager::client_datetimezone();
                $gmt                    = explode(":", $datetime_local['GMT'])[0];
                $xmlParts = '';
                /**** OwnerId is username ***/
                $general_settings = get_option(self::MAIN_OPTION_NAME, array());
                $username = isset($general_settings['username']) ? $general_settings['username'] : '';
                if ('' != $username) {
                    $xmlParts .= '<OwnerId>' . $username . '</OwnerId> ';
                }
                /**** OwnerId is username ***/
                $info        = array();
                $attributes  = explode(',', $formData['attributes']); // String to array.
                if (isset($attributes) && is_array($attributes)) {
                    foreach ($attributes as $attribute) {
                        if ($attributes_type[$attribute] == "Date" && $_POST[$attribute] != "") {
                            $_POST[$attribute]         = date('Y-m-d', strtotime($_POST[$attribute]));
                        } else if ($attributes_type[$attribute] == "DateTime" && $_POST[$attribute] != "") {
                            $_POST[$attribute]         = date('Y-m-d H:i:s', strtotime($_POST[$attribute])) . $gmt;
                        } else if (is_array($_POST[$attribute])) {
                            $_POST[$attribute]         = implode(',', $_POST[$attribute]);
                        }
                        $info[$attribute] = isset($_POST[$attribute]) ? sanitize_text_field($_POST[$attribute]) : '';
                        /*if ($attribute == 'Souscription_Newsletter') {
                            $xmlParts .= '<' . $attribute . '>' . (isset($_POST[$attribute]) && $_POST[$attribute] == 'on' ? sanitize_text_field($_POST[$attribute]) : 'off') . '</' . $attribute . '> ';
                        } else*/ {
                            $xmlParts .= '<' . $attribute . '>' . (isset($_POST[$attribute]) ? sanitize_text_field($_POST[$attribute]) : '') . '</' . $attribute . '> ';
                        }
                        if (strtolower($attribute) == 'email') {
                            $email = $_POST[$attribute];
                        }
                    }
                }
                $xmlData = ("<Data> 
                        <" . $formData['moduleID'] . ">
                        " . $xmlParts . "
                        </" . $formData['moduleID'] . ">
                        </Data>");
                //            print_r($xmlData);exit;
                $templateID = $formData['templateID'];
                $result = CS_API_Manager::data_action($formData['moduleID'], $xmlData);
                //$result['code']   ='200';
                if ($result['code'] == '200') {
                    //  Upload file
                    if (isset($_FILES) && count($_FILES > 0)) {
                        foreach ($_FILES as $fieldName => $fieldValue) {
                            $info[$fieldName]   = $_FILES[$fieldName]['name'];
                            CS_API_Manager::upload_file_action($result['guid'], $fieldName, $formData['moduleID']);
                        }
                    }
                    $activateCode = $this->create_activate_code($result['guid'], $email, $info, $formID, $listID, $redirectUrlInEmail, $unlinkedLists);
                    if ($isDoubleOptin) {
                        $email        = $info[$isEmailDoubleOptin];
                        CS_API_Manager::send_comfirm_email('double-optin', $email, $templateID, $info, $formData['confirmationMsg'], $activateCode);
                    } elseif ($isOptin) {
                        CS_API_Manager::send_comfirm_email('confirm', $email, $templateID, $info, $formData['confirmationMsg']);
                    }
                    if ($isEmailSpecific) {
                        CS_API_Manager::send_email_to_specific_email($emailSpecificIdForm, $info);
                    }
                }
                $msg = array(
                    'successMsg' => $formData['successMsg'],
                    'errorMsg' => $formData['errorMsg'],
                    'existMsg' => $formData['existMsg'],
                    'invalidMsg' => $formData['invalidMsg'],
                );
                // API return error filtering
                if (isset($result['errMessage'])) {
                    $errorContent  = '';
                    foreach (explode(',', $result['errMessage']) as $key => $value) {
                        if ('' != $value) {
                            $fieldError = explode(':', $value);
                            if (count($fieldError) > 1) {
                                $errorLabel = str_replace('_', ' ', $fieldError[0]);
                                if (trim($fieldError[1])      == "Error_MSG_Field_Required") {
                                    $errorContent .= $errorLabel . ': ' . $formData['requiredMsg'] . '<br/>';
                                } else if (trim($fieldError[1]) == "Error_MSG_Value_entered_not_valid_email") {
                                    $errorContent .= $errorLabel . ': ' . $formData['invalidMsg'] . '<br/>';
                                } else {
                                    $errorContent .= $errorLabel . ': ' . $fieldError[1] . '<br/>';
                                }
                            } else {
                                if (trim($value) == 'Error_MSG_Value_Must_Be_Unique') {
                                    $errorContent .= $formData['existMsg'] . '<br/>';
                                } else {
                                    $errorContent .= $value . '<br/>';
                                }
                            }
                        }
                    }
                    $result['message']   = $errorContent;
                }
                //            print_r($result['code'] = '200');
                //            print_r($msg);
                //            print_r($redirectUrlInForm);
                //            exit;
                wp_send_json(
                    array(
                        'status' => $result,
                        'msg' => $msg,
                        'redirect' => $redirectUrlInForm,
                    )
                );
            }
        }
        /**
         * Create activate code for Double optin
         *
         * @param string $email  - user email.
         * @param array  $info  - info.
         * @param string $formID - form ID.
         * @param array  $listIDs - lists.
         * @param string $redirectUrl - redirect url.
         * @return string - activate code.
         */
        function create_activate_code($guid, $email, $info, $formID, $listIDs, $redirectUrl, $unlinkedLists = null)
        {
            if ($email == "") {
                $data = false;
            } else {
                $data = CS_Model_Users::get_data_by_email($email, $formID);
            }
            if ($unlinkedLists != null) {
                $info['unlinkedLists'] = $unlinkedLists;
            }
            if (false == $data) {
                //$uniqid = uniqid();
                $uniqid = md5(time());
                $udata = array(
                    'guid' => $guid,
                    'email' => $email,
                    'code' => $uniqid,
                    'info' => maybe_serialize($info),
                    'frmid' => $formID,
                    'listIDs' => maybe_serialize($listIDs),
                    'redirectUrl' => $redirectUrl,
                );
                CS_Model_Users::add_record($udata);
            } else if ($data['code'] == "") {
                $uniqid                = md5(time());
                $data['code']          = $uniqid;
                $data['isSubscribe']   = '0';
                CS_Model_Users::update_element($data['id'], $data);
            } else {
                $uniqid = $data['code'];
            }
            return $uniqid;
        }
        /**
         * Use CirrusShield SMTP to send all emails
         *
         * @param string $to - reception email.
         * @param string $subject - subject of email.
         * @param string $message - message of email.
         * @param string $headers - header of email.
         * @param array  $attachments - attachments.
         */
        static function wp_mail_native($to, $subject, $message, $headers = '', $attachments = array())
        {
            require self::$plugin_dir . '/inc/function.wp_mail.php';
        }
        /**
         * To send the transactional email via cirrusshield
         * hook wp_mail
         *
         * @param string $to - reception email.
         * @param string $subject - subject of email.
         * @param string $message - message of email.
         * @param string $headers - header of email.
         * @param array  $attachments - attachments
         * @param array  $tags - tag.
         * @param string $from_name - sender name.
         * @param string $from_email - sender email.
         * @return mixed|WP_Error
         */
        static function csemail($to, $subject, $message, $headers = '', $attachments = array(), $tags = array(), $from_name = '', $from_email = '')
        {
            // Compact the input, apply the filters, and extract them back out.
            extract(apply_filters('wp_mail', compact('to', 'subject', 'message', 'headers', 'attachments')));
            if (!is_array($attachments)) {
                $attachments = explode("\n", str_replace("\r\n", "\n", $attachments));
            }
            // From email and name.
            $home_settings = get_option(CS_Manager::HOME_OPTION_NAME);
            if (isset($home_settings['sender'])) {
                $from_name = $home_settings['from_name'];
                $from_email = $home_settings['from_email'];
            } else {
                $from_email = trim(get_bloginfo('admin_email'));
                $from_name = trim(get_bloginfo('name'));
            }
            $from_email = apply_filters('wp_mail_from', $from_email);
            $from_name = apply_filters('wp_mail_from_name', $from_name);
            // Headers.
            if (empty($headers)) {
                $headers = array();
                $reply = array();
                $bcc = array();
                $cc = array();
            } else {
                if (!is_array($headers)) {
                    // Explode the headers out, so this function can take both.
                    // string headers and an array of headers.
                    $tempheaders = explode("\n", str_replace("\r\n", "\n", $headers));
                } else {
                    $tempheaders = $headers;
                }
                $headers = array();
                $reply = array();
                $bcc = array();
                $cc = array();
                // If it's actually got contents.
                if (!empty($tempheaders)) {
                    // Iterate through the raw headers.
                    foreach ((array) $tempheaders as $header) {
                        if (strpos($header, ':') === false) {
                            if (false !== stripos($header, 'boundary=')) {
                                $parts = preg_split('/boundary=/i', trim($header));
                                $boundary = trim(str_replace(array("'", '"'), '', $parts[1]));
                            }
                            continue;
                        }
                        // Explode them out.
                        list($name, $content) = explode(':', trim($header), 2);
                        // Cleanup crew.
                        $name = trim($name);
                        $content = trim($content);
                        switch (strtolower($name)) {
                            case 'content-type':
                                $headers[trim($name)] = trim($content);
                                break;
                            case 'x-cirrus-tag':
                                $headers[trim($name)] = trim($content);
                                break;
                            case 'from':
                                if (strpos($content, '<') !== false) {
                                    // So... making my life hard again?
                                    $from_name = substr($content, 0, strpos($content, '<') - 1);
                                    $from_name = str_replace('"', '', $from_name);
                                    $from_name = trim($from_name);
                                    $from_email = substr($content, strpos($content, '<') + 1);
                                    $from_email = str_replace('>', '', $from_email);
                                    $from_email = trim($from_email);
                                } else {
                                    $from_name = '';
                                    $from_email = trim($content);
                                }
                                break;
                            case 'bcc':
                                if (strpos($content, '<') !== false) {
                                    $bcc_content = substr($content, strpos($content, '<') + 1);
                                    $bcc_content = str_replace('>', '', $bcc_content);
                                    $bcc[trim($bcc_content)] = '';
                                } else {
                                    $bcc[trim($content)] = '';
                                }
                                break;
                            case 'cc':
                                if (strpos($content, '<') !== false) {
                                    $cc_content = substr($content, strpos($content, '<') + 1);
                                    $cc_content = str_replace('>', '', $cc_content);
                                    $cc[trim($cc_content)] = '';
                                } else {
                                    $bcc[trim($content)] = '';
                                }
                                break;
                            case 'reply-to':
                                if (strpos($content, '<') !== false) {
                                    $reply_content = substr($content, strpos($content, '<') + 1);
                                    $reply_content = str_replace('>', '', $reply_content);
                                    $reply[] = trim($reply_content);
                                } else {
                                    $reply[] = trim($content);
                                }
                                break;
                            default:
                                break;
                        }
                    }
                }
            }
            // Set destination addresses.
            if (!is_array($to)) {
                $to = explode(',', preg_replace('/\s+/', '', $to)); // strip all whitespace.
            }
            $processed_to = array();
            foreach ($to as $email) {
                if (is_array($email)) {
                    $processed_to[] = $email;
                } else {
                    $processed_to[$email] = '';
                }
            }
            $to = $processed_to;
            // Attachments.
            $attachment_content = array();
            if (!empty($attachments)) {
                foreach ($attachments as $attachment) {
                    $content = self::getAttachmentStruct($attachment);
                    if (!is_wp_error($content)) {
                        $attachment_content = array_merge($attachment_content, $content);
                    }
                }
            }
            // Common transformations for the HTML part.
            // If it is text/plain, New line break found.
            if (strpos($message, '</table>') === false && strpos($message, '</div>') === false) {
                if (strpos($message, "\n") !== false) {
                    if (is_array($message)) {
                        foreach ($message as &$value) {
                            $value['content'] = preg_replace('#<(https?://[^*]+)>#', '$1', $value['content']);
                            $value['content'] = nl2br($value['content']);
                        }
                    } else {
                        $message = preg_replace('#<(https?://[^*]+)>#', '$1', $message);
                        $message = nl2br($message);
                    }
                }
            }
            // Sending...
            $data = array(
                'to' => $to,
                'from' => array($from_email, $from_name),
                'cc' => $cc,
                'bcc' => $bcc,
                'replyto' => $reply,
                'subject' => $subject,
                'headers' => $headers,
                'attachment' => $attachment_content,
                'html' => $message,
            );
            try {
                $sent = CS_API_Manager::send_email($data);
                return $sent;
            } catch (Exception $e) {
                return new WP_Error($e->getMessage());
            }
        }
        /**
         * @param string $path - attachment file path
         * @return array|WP_Error
         */
        static function getAttachmentStruct($path)
        {
            $struct = array();
            try {
                if (!@is_file($path)) {
                    throw new Exception($path . ' is not a valid file.');
                }
                $filename = basename($path);
                if (!function_exists('get_magic_quotes')) {
                    /**
                     * @return bool
                     */
                    function get_magic_quotes()
                    {
                        return false;
                    }
                }
                if (!function_exists('set_magic_quotes')) {
                    /**
                     * @param $value
                     * @return bool
                     */
                    function set_magic_quotes($value)
                    {
                        return true;
                    }
                }
                $isMagicQuotesSupported = version_compare(PHP_VERSION, '5.3.0', '<') && function_exists('get_magic_quotes_runtime') && function_exists('set_magic_quotes_runtime');
                if ($isMagicQuotesSupported) {
                    // Escape linters check.
                    $getMagicQuotesRuntimeFunc = 'get_magic_quotes_runtime';
                    $setMagicQuotesRuntimeFunc = 'set_magic_quotes_runtime';
                    // Save magic quotes value.
                    $magicQuotes = $getMagicQuotesRuntimeFunc();
                    $setMagicQuotesRuntimeFunc(0);
                }
                $file_buffer = file_get_contents($path);
                $file_buffer = chunk_split(base64_encode($file_buffer), 76, "\n");
                if ($isMagicQuotesSupported) {
                    // Restore magic quotes value.
                    $setMagicQuotesRuntimeFunc($magicQuotes);
                }
                $struct[$filename] = $file_buffer;
            } catch (Exception $e) {
                return new WP_Error('Error creating the attachment structure: ' . $e->getMessage());
            }
            return $struct;
        }
        /**
         * Create custom page for form preview
         *
         * @param array $query_vars - query.
         * @return array
         */
        function csquery_vars($query_vars)
        {
            $query_vars[] = 'csform';
            return $query_vars;
        }
        /**
         * Parse request
         *
         * @param mixed $wp - object.
         */
        function csparse_request(&$wp)
        {
            if (array_key_exists('csform', $wp->query_vars)) {
                include 'inc/cs-form-preview.php';
                exit();
            }
        }
        /**
         * Load Text domain.
         */
        static function LoadTextDomain()
        {
            // Load lang file.
            $i18n_file_name = 'cslang';
            $locale = apply_filters('plugin_locale', get_locale(), $i18n_file_name);
            // $locale = 'fr_FR';
            $filename = plugin_dir_path(__FILE__) . '/lang/' . $i18n_file_name . '-' . $locale . '.mo';
            load_textdomain('cslang', $filename);
        }
        /**
         * Notice the language is difference than site's language
         */
        static function language_admin_notice()
        {
            if (!get_option(CS_Manager::LANGUAGE_OPTION_NAME)) {
                $lang_prefix = substr(get_bloginfo('language'), 0, 2);
                $lang = self::getLanguageName($lang_prefix);
                $class = 'error';
                $message = sprintf('Please note that your CirrusShield account is in %s, but CirrusShield WordPress plugin is only available in English / French for now. Sorry for inconvenience.', $lang);
                if ('en' !== $lang_prefix && 'fr' !== $lang_prefix) {
                    echo ("<div class=\"$class\" style='margin-left: 2px;margin-bottom: 4px;'> <p>$message<a class='' href='?dismiss_admin_lang_notice=1'> No problem...</a></p></div>");
                }
            }
        }
        /**
         * Notice wp_mail is not possible
         */
        static function wpMailNotices()
        {
            if (self::$wp_mail_conflict) {
                echo ('<div class="error"><p>' . __('You cannot use CirrusShield SMTP now because wp_mail has been declared by another process or plugin. ', 'cslang') . '</p></div>');
            }
        }
        /**
         * Names of languages.
         *
         * @param string $prefix - language.
         * @return mixed
         */
        public static function getLanguageName($prefix = 'en')
        {
            $lang = array();
            $lang['de'] = 'Deutsch';
            $lang['en'] = 'English';
            $lang['zh'] = 'Ã¤Â¸Â­Ã¦ÂÂ';
            $lang['ru'] = 'Ã?Â ÃÂÃ?Ã?Ã?ÂºÃ?Â¸Ã?Â¹';
            $lang['fi'] = 'suomi';
            $lang['fr'] = 'FranÃÂ§ais';
            $lang['nl'] = 'Nederlands';
            $lang['sv'] = 'Svenska';
            $lang['it'] = 'Italiano';
            $lang['ro'] = 'RomÃÂ¢nÃÂ';
            $lang['hu'] = 'Magyar';
            $lang['ja'] = 'Ã¦ÂÂ¥Ã¦ÂÂ¬Ã¨ÂªÂ';
            $lang['es'] = 'EspaÃÂ±ol';
            $lang['vi'] = 'TiÃ¡ÂºÂ¿ng ViÃ¡Â»Ât';
            $lang['ar'] = 'ÃÂ§ÃÂÃÂ¹ÃÂ±ÃÂ¨ÃÂÃÂ©';
            $lang['pt'] = 'PortuguÃÂªs';
            $lang['pb'] = 'PortuguÃÂªs do Brasil';
            $lang['pl'] = 'Polski';
            $lang['gl'] = 'galego';
            $lang['tr'] = 'Turkish';
            $lang['et'] = 'Eesti';
            $lang['hr'] = 'Hrvatski';
            $lang['eu'] = 'Euskera';
            $lang['el'] = 'ÃÂÃÂ»ÃÂ»ÃÂ·ÃÂ½ÃÂ¹ÃÂºÃÂ¬';
            $lang['ua'] = 'Ã?Â£Ã?ÂºÃÂÃ?Â°ÃÂÃ?Â½Ã?ÃÂÃ?ÂºÃ?Â°';
            $lang['ko'] = 'Ã­ÂÂÃªÂµÂ­Ã¬ÂÂ´';
            return $lang[$prefix];
        }
        /**
         * Create language sidebar for wpml plugin.
         */
        public function cscreate_language_sidebar()
        {
            $languages = apply_filters('wpml_active_languages', array());
            $page = isset($_GET['page']) ? sanitize_text_field($_GET['page']) : '';
            $action = isset($_GET['action']) ? sanitize_text_field($_GET['action']) : '';
            $frmID = isset($_GET['id']) ? sanitize_text_field($_GET['id']) : '';
            $pID = isset($_GET['pid']) ? sanitize_text_field($_GET['pid']) : '';
            $parent = true;
            if ('' !== $frmID && '' !== $pID) {
                $lang = CS_Forms_Lang::get_lang($frmID, $pID);
                $parent = false;
            } else {
                $lang = ICL_LANGUAGE_CODE;
                if ('' !== $frmID && '' === $pID) {
                    $pID = $frmID;
                }
            }
            if ('cspage_form' === $page && 'edit' === $action) {
            ?>
                <div class="panel panel-default text-left box-border-box  small-content">
                    <div class="panel-heading"><strong><?php esc_attr_e('About CirrusShield', 'cslang'); ?></strong></div>
                    <div class="panel-body">
                        <p>
                            <label for='csform_language'><?php esc_attr_e('Language of this form:', 'cslang'); ?> </label>
                            <select id="csform_lang" name="csform_lang" data-selected="">
                                <?php
                                foreach ($languages as $language) {
                                    $selected = ($language['code'] == $lang) ? 'selected' : '';
                                    if ($language['code'] == $lang && true === $parent) {
                                        $option_text = '<option value="" ' . $selected . '>' . $language['native_name'] . '</option>';
                                    } else {
                                        $exist = CS_Forms_Lang::get_form_ID($pID, $language['language_code']);
                                        if (null === $exist) {
                                            continue;
                                        } else {
                                            $option_text = ('selected' === $selected) ? sprintf('<option value="" selected>%s</option>', $language['native_name']) : sprintf('<option value="?page=%s&action=%s&pid=%s&lang=%s" %s >%s</option>', esc_attr($_REQUEST['page']), 'edit', absint($pID), $language['language_code'], $selected, $language['native_name']);
                                        }
                                    }
                                    echo $option_text;
                                }
                                ?>
                            </select>
                        </p>
                        <div class="csform_translate">
                            <p>
                                <label><?php esc_attr_e('Translate this form', 'cslang'); ?></label>
                            </p>
                            <table width="100%" class="csform_trans_table" style="border: 1px solid #8cceea;">
                                <tr>
                                    <?php
                                    foreach ($languages as $language) {
                                        if ($language['code'] == $lang) {
                                            continue;
                                        }
                                    ?>
                                        <th style="text-align: center;"><img src="<?php echo esc_url($language['country_flag_url']); ?>"></th>
                                    <?php
                                    }
                                    ?>
                                </tr>
                                <tr style="background-color: #EFF8FC;">
                                    <?php
                                    foreach ($languages as $language) {
                                        if ($language['code'] == $lang) {
                                            continue;
                                        }
                                        if ('' === $pID) {
                                            $img_src = plugins_url('img/add_translation_disabled.png', __FILE__);
                                            $td = '<img src="' . $img_src . '" style="margin:2px;">';
                                        } else {
                                            $exist = CS_Forms_Lang::get_form_ID($pID, $language['language_code']);
                                            if (null === $exist) {
                                                $img_src = plugins_url('img/add_translation.png', __FILE__);
                                                $href = sprintf('<a class="cs-form-redirect" href="?page=%s&action=%s&pid=%s&lang=%s" style="width: 20px; text-align: center;padding: 2px 1px;">', esc_attr($_REQUEST['page']), 'edit', absint($pID), $language['language_code']);
                                                $td = $href . '<img src="' . $img_src . '" style="margin:2px;"></a>';
                                            } else {
                                                $img_src = plugins_url('img/edit_translation.png', __FILE__);
                                                $href = sprintf('<a class="cs-form-redirect" href="?page=%s&action=%s&id=%s&pid=%s&lang=%s" style="width: 20px; text-align: center;padding: 2px 1px;">', esc_attr($_REQUEST['page']), 'edit', absint($exist), absint($pID), $language['language_code']);
                                                $td = $href . '<img src="' . $img_src . '" style="margin:2px;"></a>';
                                            }
                                        }
                                    ?>
                                        <td style="text-align: center;"><?php echo $td; ?></td>
                                    <?php
                                    }
                                    ?>
                                </tr>
                            </table>
                        </div>
                        <?php if (isset($_GET['pid'])) { ?>
                            <div class="cs-form-duplicate">
                                <button class="btn btn-default cs-duplicate-btn"><?php esc_attr_e('Copy content from origin form', 'cslang'); ?></button>
                                <span class="cs-spin"><i class="fa fa-circle-o-notch fa-spin fa-lg"></i>&nbsp;&nbsp;</span>
                                <i title="<?php echo esc_attr_e('Copy content from origin form', 'cslang'); ?>" data-container="body" data-toggle="popover" data-placement="left" data-content="<?php echo esc_attr_e('You can copy contents from origin form. You need to translate the contents by this language.', 'cslang'); ?>" data-html="true" class="fa fa-question-circle popover-help-form"></i>
                            </div>
                        <?php } ?>
                    </div>
                </div>
<?php
            }
        }
        public function ajax_get_country_prefix()
        {
            check_ajax_referer('csfront_ajax_nonce', 'security');
            $sms_manager = new CS_SMS_Code();
            $country_list = $sms_manager->get_sms_code_list();
            $country_list_html = '';
            foreach ($country_list as $item => $value) {
                $flg_url = plugins_url('img/flags/', __FILE__) . strtolower($item) . '.png';
                $item_html = '<li class="cs-country-prefix" data-country-code="' . $item . '" data-dial-code="' . $value["code"] . '"><div class="cs-flag-box"><div class="cs-flag ' . $item . '" style="background-image: url(' . $flg_url . ')"></div><span>' . $value['name'] . '</span><span class="cs-dial-code">+' . $value['code'] . '</span></div></li>';
                $country_list_html .= $item_html;
            }
            wp_send_json($country_list_html);
        }
    }
    add_action('cirrusshield_init', 'cirrusshield_init');
    add_filter('widget_text', 'do_shortcode');
    /**
     * Plugin entry point Process.
     */
    function cirrusshield_init()
    {
        CS_Manager::LoadTextDomain();
        new CS_Manager();
    }
    do_action('cirrusshield_init');
}
